import { jsx, jsxs } from "react/jsx-runtime";
import assert from "assert";
import { Box } from "../Box/Box.mjs";
import { Text } from "../Text/Text.mjs";
import { ButtonIcon } from "../ButtonIcon/ButtonIcon.mjs";
import { buildDataAttributes } from "../private/buildDataAttributes.mjs";
import { clearGutter } from "./Tag.css.mjs";
import { IconClear } from "../icons/IconClear/IconClear.mjs";
const tagSizes = ["small", "standard"];
const paddingXForSize = {
  small: "xsmall",
  standard: "small"
};
const Tag = ({
  onClear,
  clearLabel = "Clear",
  size = "standard",
  data,
  id,
  icon,
  children,
  ...restProps
}) => {
  assert(
    typeof children === "undefined" || typeof children === "string",
    "Tag may only contain a string"
  );
  assert(
    !icon || icon.props.size === void 0 || icon.props.tone === void 0,
    "Icons cannot set the 'size' or 'tone' prop when passed to a Tag component"
  );
  return /* @__PURE__ */ jsx(
    Box,
    {
      id,
      display: "flex",
      ...buildDataAttributes({ data, validateRestProps: restProps }),
      children: /* @__PURE__ */ jsxs(
        Box,
        {
          display: "flex",
          minWidth: 0,
          alignItems: "center",
          background: "neutralLight",
          paddingY: "xxsmall",
          paddingX: paddingXForSize[size],
          paddingRight: onClear ? "xsmall" : paddingXForSize[size],
          borderRadius: "full",
          children: [
            /* @__PURE__ */ jsx(Box, { minWidth: 0, title: children, children: /* @__PURE__ */ jsxs(Text, { size, baseline: false, maxLines: 1, children: [
              icon,
              " ",
              children
            ] }) }),
            onClear ? /* @__PURE__ */ jsx(
              Box,
              {
                flexShrink: 0,
                marginLeft: "xxsmall",
                className: clearGutter,
                children: /* @__PURE__ */ jsx(
                  ButtonIcon,
                  {
                    id: id ? `${id}-clear` : void 0,
                    icon: /* @__PURE__ */ jsx(IconClear, {}),
                    label: clearLabel,
                    tone: "secondary",
                    size: "small",
                    variant: "transparent",
                    onClick: onClear
                  }
                )
              }
            ) : null
          ]
        }
      )
    }
  );
};
export {
  Tag,
  tagSizes
};
